<?php
/**
 * TPC! Memory Usage Overview
 * 
 * @package TPC_Memory_Usage
 */

// Prevent direct calls to this file
if (!function_exists('add_action')) {
	header('Status: 403 Forbidden');
	header('HTTP/1.1 403 Forbidden');
	exit();
}

// Variable by reference for $_SERVER for simplification
$s = &$_SERVER;

// Complete security check
$security = tpcmem_check_security();
?>

<div class="wrap">
<?php screen_icon('options-general'); ?>
<h2><?php echo esc_html('TPC! ' . $title); ?></h2>

<div id="tpcmem-overview-tabs">
	<ul>
		<li><a href="#tpcmem-server">Server</a></li>
		<li><a href="#tpcmem-php">PHP</a></li>
		<li><a href="#tpcmem-mysql">MySQL</a></li>
		<li><a href="#tpcmem-misc">WordPress</a></li>
		<li><a href="#tpcmem-security">Security</a></li>
	</ul>
	<div id="tpcmem-server">
		<table cellspacing="0">
			<tr><th><?php esc_html_e('OS/Server:'); ?></th><td><?php echo esc_html(php_uname()); ?></td></tr>
			<tr><th><?php esc_html_e('Address:'); ?></th><td><?php echo esc_html($s['SERVER_ADDR']); ?></td></tr>
			<tr><th><?php esc_html_e('Name:'); ?></th><td><?php echo esc_html($s['SERVER_NAME']); ?></td></tr>
			<tr><th><?php esc_html_e('Software:'); ?></th><td><?php echo esc_html($s['SERVER_SOFTWARE']); ?></td></tr>
			<tr><th><?php esc_html_e('Protocol:'); ?></th><td><?php echo esc_html($s['SERVER_PROTOCOL']); ?></td></tr>
			<tr><th><?php esc_html_e('Document Root:'); ?></th><td><?php echo esc_html($s['DOCUMENT_ROOT']); ?></td></tr>
			<tr><th><?php esc_html_e('Client IP:'); ?></th><td><?php echo esc_html($s['REMOTE_ADDR']); ?></td></tr>
			<tr><th><?php esc_html_e('Client Hostname:'); ?></th><td><?php echo esc_html(gethostbyaddr($s['REMOTE_ADDR'])); ?></td></tr>
			<tr><th><?php esc_html_e('Client Port:'); ?></th><td><?php echo esc_html($s['REMOTE_PORT']); ?></td></tr>
			<tr><th><?php esc_html_e('Server Admin:'); ?></th><td><?php echo esc_html($s['SERVER_ADMIN']); ?></td></tr>
			<tr><th><?php esc_html_e('Server Port:'); ?></th><td><?php echo esc_html($s['SERVER_PORT']); ?></td></tr>
			<tr><th><?php esc_html_e('Server Signature:'); ?></th><td><?php echo trim($s['SERVER_SIGNATURE']) == '' ? 'OFF' : esc_html($s['SERVER_SIGNATURE']); ?></td></tr>
		</table>
	</div>
	<div id="tpcmem-php">
		<table cellspacing="0">
			<tr>
				<th><?php esc_html_e('PHP Version:'); ?></th>
				<td><?php echo esc_html(PHP_VERSION); ?></td>
			</tr>
			<tr>
				<th><?php esc_html_e('Zend Engine:'); ?></th>
				<td><?php echo esc_html(zend_version()); ?></td>
			</tr>
			<tr>
				<th><?php esc_html_e('PHP Memory Limit:'); ?></th>
				<td><?php echo esc_html(ini_get('memory_limit')); ?></td>
			</tr>
			<tr>
				<th><?php esc_html_e('Memory Usage Sampling:'); ?></th>
				<td><?php echo esc_html(size_format(memory_get_usage(), 2)); ?></td>
			</tr>
			<tr>
				<th><?php esc_html_e('Loaded Extensions:'); ?></th>
				<td>
					<span id="tpcmem-php-loaded-extensions-content" style="display: none;">
					<?php echo esc_html(implode(', ', get_loaded_extensions())); ?>
					</span><a href="javascript:void(0)" onclick="javascript:void(0)" id="tpcmem-php-loaded-extensions">View</a>
				</td>
			</tr>
			<tr>
				<th><?php esc_html_e('PHP Include Path:')?></th>
				<td><?php echo esc_html(get_include_path()); ?></td>
			</tr>
			<tr>
				<th><?php esc_html_e('Maximum Upload:'); ?></th>
				<td><?php echo esc_html(ini_get('upload_max_filesize')); ?></td>
			</tr>
		</table>
	</div>
	<?php
	global $wpdb, $wp_version;
	
	$mysql_status = array();
	$mysql_vars   = array();
	
	foreach ($wpdb->get_results('SHOW GLOBAL STATUS') as $result) {
		$mysql_status[$result->Variable_name] = $result->Value;
	}
	
	foreach ($wpdb->get_results('SHOW GLOBAL VARIABLES') as $result) {
		$mysql_vars[$result->Variable_name] = $result->Value;
	}
	
	$uptime_days = $mysql_status['Uptime'] / 86400;
	$uptime_hours = ($uptime_days - (int) $uptime_days) * 24;
	$uptime_minutes = ($uptime_hours - (int) $uptime_hours) * 60;
	$uptime_seconds = ($uptime_minutes - (int) $uptime_minutes) * 60;
	$uptime_string = (int) $uptime_days . ' days, ' . (int) $uptime_hours . ' hours, ' . (int) $uptime_minutes . ' minutes, and ' . (int) $uptime_seconds . ' seconds';
	?>
	<div id="tpcmem-mysql">
		<table cellspacing="0">
			<tr>
				<th><?php esc_html_e('Database:'); ?></th>
				<td><?php echo $mysql_vars['version_comment']; ?></td>
			</tr>
			<tr>
				<th><?php esc_html_e('Version:'); ?></th>
				<td><?php echo $mysql_vars['version']; ?></td>
			</tr>
			<tr>
				<th><?php esc_html_e('Uptime:'); ?></th>
				<td><?php echo $uptime_string; ?></td>
			</tr>
			<tr>
				<th><?php esc_html_e('Hostname:'); ?></th>
				<td><?php echo $mysql_vars['hostname']; ?></td>
			</tr>
			<tr>
				<th><?php esc_html_e('DATE Format:'); ?></th>
				<td><?php echo $mysql_vars['date_format']; ?></td>
			</tr>
			<tr>
				<th><?php esc_html_e('DATETIME Format:'); ?></th>
				<td><?php echo $mysql_vars['datetime_format']; ?></td>
			</tr>
		</table>
	</div>
	<div id="tpcmem-misc">
		<table cellspacing="0">
			<tr>
				<th><?php esc_html_e('WordPress Version:'); ?></th>
				<td><?php echo esc_html($wp_version); ?></td>
			</tr>
			<tr>
				<th><?php esc_html_e('WordPress Memory Limit:'); ?></th>
				<td><?php echo esc_html(WP_MEMORY_LIMIT); ?></td>
			</tr>
			<tr>
				<th><?php esc_html_e('WordPress DB Hostname:'); ?></th>
				<td><?php echo esc_html(DB_HOST); ?></td>
			</tr>
			<tr>
				<th><?php esc_html_e('WordPress Database Name:'); ?></th>
				<td><?php echo esc_html(DB_NAME); ?></td>
			</tr>
			<tr>
				<th><?php esc_html_e('Auto-Save Interval:'); ?></th>
				<td><?php echo (int) AUTOSAVE_INTERVAL . ' seconds'; ?></td>
			</tr>
			<tr>
				<th><?php esc_html_e('Query Logging:'); ?></th>
				<td><?php echo defined('SAVEQUERIES') && SAVEQUERIES ? 'Yes' : 'No'; ?></td>
			</tr>
			<tr>
				<th><?php esc_html_e('Debugging:'); ?></th>
				<td><?php echo defined('WP_DEBUG') && WP_DEBUG ? 'Yes' : 'No'; ?></td>
			</tr>
			<tr>
				<th><?php esc_html_e('JavaScript Compression:'); ?></th>
				<td><?php echo defined('COMPRESS_SCRIPTS') && COMPRESS_SCRIPTS ? 'Yes' : 'No'; ?></td>
			</tr>
			<tr>
				<th><?php esc_html_e('CSS Compression:'); ?></th>
				<td><?php echo defined('COMPRESS_CSS') && COMPRESS_CSS ? 'Yes' : 'No'; ?></td>
			</tr>
			<tr>
				<th><?php esc_html_e('GZip Compression:'); ?></th>
				<td><?php echo defined('ENFORCE_GZIP') && ENFORCE_GZIP ? 'Yes' : 'No'; ?></td>
			</tr>
			<tr>
				<th><?php esc_html_e('JavaScript Concatenation:'); ?></th>
				<td><?php echo defined('CONCATENATE_SCRIPTS') && CONCATENATE_SCRIPTS ? 'Yes' : 'No'; ?></td>
			</tr>
		</table>
	</div>
	<div id="tpcmem-security">
		<?php if ($security['register_globals']): ?>
		<div class="msgError">
		<p>The <strong>register_globals</strong> setting in <em>php.ini</em> is set to ON.  This feature has been depreciated 
		as of PHP 5.3 and removed as of PHP 6.0.  Relying on this feature is <em>highly</em> discouraged.</p>
		</div>
		<?php else: ?>
		<div class="msgSuccess">
		<p>The <strong>register_globals</strong> setting in <em>php.ini</em> is set to OFF.</p>
		</div>
		<?php endif; ?>
		
		<?php if ($security['safe_mode']): ?>
		<div class="msgWarning">
		<p>The <strong>safe_mode</strong> setting in <em>php.ini</em> is set to ON.  This feature is depreciated in PHP 5.3 
		and is removed in PHP 6.0.  Relying on this feature is architecturally incorrect, as this should not be solved at 
		the PHP level.</p>
		</div>
		<?php else: ?>
		<div class="msgSuccess">
		<p>The <strong>safe_mode</strong> setting in <em>php.ini</em> is set to OFF.  While relying on this feature is 
		architecturally incorrect because this should not be solved at the PHP level, many ISP's still use safe mode in 
		shared hosting situations due to limitations at the level the web server and OS.</p>
		</div>
		<?php endif; ?>
		
		<?php if ($security['display_errors'] == '1'): ?>
		<div class="msgWarning">
		<p>The <strong>display_errors</strong> setting in <em>php.ini</em> is set to ON.  This means that PHP errors, and 
		warnings are being displayed. Such warnings can cause sensitive information to be revealed to users (paths, database 
		queries, etc.).</p>
		</div>
		<?php else: ?>
		<div class="msgSuccess">
		<p>The <strong>display_errors</strong> setting in <em>php.ini</em> is set to OFF.  This is the proper setting for a 
		production environment.</p>
		</div>
		<?php endif; ?>
		
		<?php if (!$security['mod_security']): ?>
		<div class="msgWarning">
		<p><strong>mod_security</strong> for Apache is not installed. ModSecurity can help protect your server against SQL 
		injections, XSS attacks, and a variety of other attacks. The Apache module is available for free at 
		<a href="http://www.modsecurity.org" title="ModSecurity">http://www.modsecurity.org</a>.</p>
		</div>
		<?php elseif ('N/A' == $security['mod_security']): ?>
		<div class="msgWarning">
		<p>Unable to determine if <strong>mod_security</strong> for Apache is installed. ModSecurity can help protect your server against SQL 
		injections, XSS attacks, and a variety of other attacks. The Apache module is available for free at 
		<a href="http://www.modsecurity.org" title="ModSecurity">http://www.modsecurity.org</a>.</p>
		</div>
		<?php else: ?>
		<div class="msgSuccess">
		<p><strong>mod_security</strong> for Apache is installed and actively protecting your web server.</p>
		</div>
		<?php endif; ?>
		
		<?php if ($security['magic_quotes']): ?>
		<div class="msgWarning">
		<p><strong>Magic Quotes</strong> is set to ON. This feature has been depreciated as of PHP 5.3 and removed as of PHP 
		6.0. Relying on this feature is highly discouraged. It is preferred to code with magic quotes off and to instead 
		escape the data at runtime, as needed.</p>
		</div>
		<?php else: ?>
		<div class="msgSuccess">
		<p><strong>Magic Quotes</strong> is set to OFF. This is the proper setting for any environment.</p>
		</div>
		<?php endif; ?>
		
		<?php if ($security['server_signature']): ?>
		<div class="msgWarning">
		<p>Apache's <strong>ServerSignature</strong> directive is set to on. This means that your server software version, and 
		other important details are public, which can give hackers information necessary to exploit version and software-specific 
		vulnerabilities.</p>
		</div>
		<?php else: ?>
		<div class="msgSuccess">
		<p>Apache's <strong>ServerSignature</strong> directive is set to off. This prevents hackers from gaining information 
		that could help them exploit vulnerabilities based on your specific server software version.</p>
		</div>
		<?php endif; ?>
	</div>
</div>

<p id="tpc-footer-text">Brought to you by Chris Strosser @ <a href="http://webjawns.com/">webjawns.com</a></p>

<script type="text/javascript">
(function($) {
	$(document).ready(function() {
		$("#tpcmem-overview-tabs").tabs({
			fx: { opacity: 'toggle' }
		});

		$("#tpcmem-php-loaded-extensions").click(function() {
			if ($(this).html() == 'Hide') {
				$('#tpcmem-php-loaded-extensions-content').fadeOut();
				$(this).html('Show');
			} else {
				$('#tpcmem-php-loaded-extensions-content').fadeIn();
				$(this).html('Hide');
			}
		});
	});
})(jQuery);
</script>