<?php
/**
 * TPC! Memory Usage Administration API
 * 
 * @package TPC_Memory_Usage
 * @subpackage Administration
 */

function tpcmem_admin_init() {
	global $tpcmem;
	
	if (is_tpcmem_capable()) {
		add_action('wp_dashboard_setup', 'tpcmem_admin_dashboard');
		add_action('admin_footer_text', 'tpcmem_admin_footer');
	}
	
	add_filter('tpcmem_mb_suffix', 'tpcmem_bytes_to_mb');
	add_filter('tpcmem_mb_suffix', create_function('$a', '{return $a."M";}'));
	add_filter('tpcmem_percent_of_limit', 'tpcmem_bytes_to_mb');
	add_filter('tpcmem_percent_of_limit', 'tpcmem_get_percent_of_limit');
	
	register_setting('tpc_memory_usage', 'tpc_memory_usage_location');
	register_setting('tpc_memory_usage', 'tpc_memory_usage_graph');
	register_setting('tpc_memory_usage', 'tpc_memory_usage_admin_footer');
	register_setting('tpc_memory_usage', 'tpc_memory_usage_log');
	register_setting('tpc_memory_usage', 'tpc_memory_usage_allowed_users');
	
	if (isset($_GET['page'])) {
		switch ($_GET['page']) {
			case 'tpc-memory-usage':
				wp_enqueue_style('tpcmem');
				wp_enqueue_script('jquery-ui-tabs');
				break;
			default:
				break;
		}
	}
}

/**
 * Register TPC! Memory Usage admin menu items.
 * 
 * @uses add_menu_page()
 * @return void
 */
function tpcmem_admin_menu() {
	add_menu_page(__('TPC! Memory Usage'), __('Memory Usage'), 'level_8', TPCMEM_FOLDER, 'tpcmem_admin_page', '');
	tpcmem_add_page(__('System Overview'), __('System Overview'), 'level_8', TPCMEM_FOLDER, 'tpcmem_admin_page');
	tpcmem_add_page(__('Memory Usage Settings'), __('Settings'), 'level_8', 'tpcmem-settings', 'tpcmem_admin_page');
}

/**
 * The bootstrap for loading TPC! Memory Usage admin pages.
 * 
 * @return void
 */
function tpcmem_admin_page() {
	global $title;
	
	$title = get_admin_page_title();
	
	switch ($_GET['page']) {
		case 'tpc-memory-usage':
			require_once('admin/overview.php');
			break;
		case 'tpcmem-settings':
			require_once('admin/settings.php');
			break;
		default:
			break;
	}
}

/**
 * Add a submenu item to the TPC! Memory Usage admin menu.
 * 
 * @param $page_title
 * @param $menu_title
 * @param $access_level
 * @param $file
 * @param $function
 * @return void
 */
function tpcmem_add_page($page_title, $menu_title, $access_level, $file, $function = '') {
	add_submenu_page(TPCMEM_FOLDER, $page_title, $menu_title, $access_level, $file, $function);
}

/**
 * Add the TPC! Memory Usage dashboard widget.
 * 
 * @uses wp_enqueue_style()
 * @uses wp_add_dashboard_widget()
 */
function tpcmem_admin_dashboard() {
	wp_enqueue_style('tpcmem');
	wp_add_dashboard_widget('tpc_memory_usage_dashboard', 'Memory Usage Overview', 'tpcmem_display_dashboard_widget');
}