<?php
/**
 * TPC! Memory Usage Core API
 * 
 * @package TPC_Memory_Usage
 * @subpackage Core
 */

if (!defined('ABSPATH'))
	die('-1');

function tpcmem_init() {
	global $tpcmem;
	
	// Create new logger instance
	$tpcmem = tpcmem::getInstance();
	$tpcmem->record(array('action' => 'Started tpcmem'));
	
	tpcmem_register_checkpoints();
	
	// If comment display is turned on, show HTML comments in proper location on page
	if (is_tpcmem_comments_on()) {
		switch (get_option('tpc_memory_usage_location')) {
			case 'header':
				add_action('wp_header', 'tpcmem_display_comments');
				add_action('admin_head', 'tpcmem_display_comments');
				break;
			
			case 'footer':
				add_action('wp_footer', 'tpcmem_display_comments');
				add_action('admin_footer', 'tpcmem_display_comments');
				break;
			
			default:
				// Don't display as HTML comments
				break;
		}
	}
}

function tpcmem_register_checkpoints() {
	$checkpoints = tpcmem_get_checkpoints();
	
	if (!is_array($checkpoints))
		return false;
	
	foreach ((array) $checkpoints as $c) {
		add_action(
			$c['hook'],
			create_function('$a',
				'{
				   tpcmem_checkpoint(array(
					"hook" => "' . esc_html($c['hook']) . '",
					"action" =>	"' . esc_html($c['action']) . '"
				   ));
				 }'), 15, 1);
	}
}

function tpcmem_get_checkpoints() {
	$checkpoints = array(
		array('hook' => 'sanitize_comment_cookies', 'action' => 'Sanitize comment cookies'),
		array('hook' => 'setup_theme', 'action' => 'Setup theme'),
		array('hook' => 'init', 'action' => 'WordPress initialization'),
		array('hook' => 'wp_head', 'action' => 'Display front-end header'),
		array('hook' => 'publish_future_post', 'action' => 'Publish future post'),
		array('hook' => 'do_feed_rdf', 'action' => 'RDF feed'),
		array('hook' => 'do_feed_rss', 'action' => 'RSS feed'),
		array('hook' => 'do_feed_rss2', 'action' => 'RSS2 feed'),
		array('hook' => 'do_feed_atom', 'action' => 'Atom feed'),
		array('hook' => 'do_pings', 'action' => 'Pings'),
		array('hook' => 'admin_print_scripts', 'action' => 'Print admin scripts'),
		array('hook' => 'admin_print_footer_scripts', 'action' => 'Print admin footer scripts'),
		array('hook' => 'admin_print_styles', 'action' => 'Print admin styles'),
		array('hook' => 'pre_post_update', 'action' => 'Pre-post update'),
		array('hook' => 'publish_post', 'action' => 'Publish post'),
		array('hook' => 'future_post', 'action' => 'Future post'),
		array('hook' => 'future_page', 'action' => 'Future page'),
		array('hook' => 'save_post', 'action' => 'Save post'),
		array('hook' => 'template_redirect', 'action' => 'Template redirect'),
		array('hook' => 'edit_post', 'action' => 'Edit post'),
		array('hook' => 'edit_form_advanced', 'action' => 'Edit form advanced'),
		array('hook' => 'shutdown', 'action' => 'Shutdown'),
	);
	return $checkpoints;
}

function tpcmem_checkpoint(Array $data) {
	global $tpcmem;
	
	$tpcmem->record($data);
	
	// Shutting down...
	if ($data['hook'] == 'shutdown') {
		// Check if any new records were set
		$record = get_option('tpc_memory_usage_log_highest');
		
		if (!is_array($record))
			return false;
		
		$current = $tpcmem->scriptPeak();
		
		if ($current['usage'] > $record['usage'])
			update_option('tpc_memory_usage_log_highest', $current);
		
		// Send notification e-mail if memory limit exceeded
		if ($current['usage'] > get_option('tpc_memory_usage_email_high_usage'))
			tpcmem_max_memory_notification(get_option('tpc_memory_usage_email_high_usage'), $current['usage']);
	}
}

function tpcmem_max_memory_notification($memoryExceeded, $memoryUsage) {
	$subject  = sprintf( __('[%1$s] High memory usage notification'), get_option('blogname') );
	$message  = sprintf( __('WordPress memory usage exceeded %1$s MB'), $memoryExceeded ) . "\r\n";
	$message .= sprintf( __('WordPress peak memory usage: %1$s MB'), $memoryUsage ) . "\r\n";

	return @wp_mail( get_option('admin_email'), $subject, $message );
}

function get_default_tpcmem_log_to_edit() {
	return array('hook' => 'unknown', 'action' => 'Unknown', 'time' => time(), 'usage' => '');
}

/**
 * Whether or not the current user is allowed to view memory usage information.
 * 
 * @return bool True if allowed, false otherwise.
 */
function is_tpcmem_capable() {
	$allowed = get_option('tpc_memory_usage_allowed_users');
	if ('all' == $allowed || ($allowed == 'admin' && current_user_can('manage_options')))
		return true;
	return false;
}

function is_tpcmem_enabled() {
	if ('off' == get_option('tpc_memory_usage_allowed_users'))
		return true;
	return false;
}

function is_tpcmem_comments_on() {
	if ('none' == get_option('tpc_memory_usage_location'))
		return false;
	return true;
}

/**
 * Retrieve the default value for the dashboard graph (peak or current).
 * 
 * @return int Either peak or current memory usage in bytes.
 */
function tpcmem_graph_peak_or_current() {
	global $tpcmem;
	
	if ('peak' == get_option('tpc_memory_usage_graph')) {
		$mem = $tpcmem->peak();
	} else {
		$mem = $tpcmem->current();
	}
	
	return $mem;
}